# =============================================================================
# Minet CLI Constants
# =============================================================================
#
# Miscellaneous cli-related constants.
#
DEFAULT_CONTENT_FOLDER = "downloaded"
DEFAULT_PREBUFFER_BYTES = 3_000_000  # 3mb
